@@ -11,11 +11,12 @@ except (ModuleNotFoundError, ValueError):
     from .separate.aggregation import aggregate
     
     
-__version__ = '0.9.7'
+__version__ = '1.0.6'
 from .load_datasets import load_images
 from .symbolic_representation import (image_compress, image_decompress, ABBAbase, ABBA,
-                                      get_patches, patched_reconstruction, fabba_model,
+                                      get_patches, patched_reconstruction, fABBA,
                                       symbolsAssign, fillna)
+
 from .symbolic_representation import _compress as compress
 from .symbolic_representation import _inverse_compress as inverse_compress
-from .digitization import digitize, inverse_digitize, wcss, calculate_group_centers
+from .digitization import digitize, inverse_digitize, quantize, wcss, calculate_group_centers
